@@ -9,7 +9,8 @@
 #define ERROR_WRITING_COST_FUNCTIONS 7
 #define ERROR_WRITING_LOSS_OUTPUT 8
 #define ERROR_NO_DATA 9
-#define ERROR_OPENING_DATABASE 10
+#define ERROR_PENALTY_NOT_NUMERIC 10
+#define ERROR_WRITING_SEGMENTS_OUTPUT 11
 
 int PeakSegFPOP_disk(char *, char *);
 
